==> manydhcp2.5.2.tar.bz2: manydhcp/login.php <==
<?php
  ///////////////////////////////////////////////////
  // Вход в систему
  ///////////////////////////////////////////////////
  $lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("lang/".$lang."/".$lang.".php")) include "lang/".$lang."/".$lang.".php";
     else include "lang/ru/ru.php";

  require_once "config.php";
  require_once "utils/functions.php";

  if(empty($_POST['login'])) {puterrorclr2("Кажется вы забыли ввести логин."); exit();}
  if(empty($_POST['password'])) {puterrorclr2("Кажется вы забыли ввести пароль."); exit();}
  if(strlen($_POST['login'])>200) {puterrorclr2("Логин слишком большой, используйте пожалуйста не больше 100 символов."); exit();}
  if(strlen($_POST['password'])>200) {puterrorclr2("Пароль слишком большой, используйте пожалуйста не больше 100 символов."); exit();}

  if(isset($_POST['login'])) $login=trim($_POST['login']);
    else $login="";
     if (empty($login)) {puterrorclr2("Пробелы не подойдут в качестве логина..."); exit();}

  if(isset($_POST['password'])) $password=trim($_POST['password']);
    else $password="";
     if (empty($password)) {puterrorclr2("Пробелы не подойдут в качестве пароля..."); exit();}

  $_POST['login'] = rep($_POST['login']);
  $_POST['password'] = rep($_POST['password']);

//  $_POST['login'] = str_replace("'","`",$_POST['login']);
//  $_POST['password'] = str_replace("'","`",$_POST['password']);
//  $_POST['login'] = htmlspecialchars(stripslashes($_POST['login']));
//  $_POST['password'] = htmlspecialchars(stripslashes($_POST['password']));

  $query = "SELECT login_id, login, pass FROM `tbl_logins` WHERE `login`='".$_POST['login']."' ";
  $result = mysql_query($query);
  if (!$result) {puterrorclr2(mysql_error()); exit();}
      $result2 = mysql_fetch_array($result);
      $ident = $result2['login_id'];
  //Проверяем правильность пароля и вычисляем его для хранения в базе
  $passwrd = md5($_POST['password']);
     if($passwrd == $result2['pass'])
     {
       setcookie("passwrd", $passwrd, time()+3600*8);
       setcookie("ident", $ident, time()+3600*8);

       echo "<HTML><HEAD>
             <META HTTP-EQUIV='Refresh' CONTENT='0; URL=main.php'>
             </HEAD>";
     }
     else {puterrorclr2($TEXT['error-loginform1']); exit();}
?>

==> manydhcp2.7.2.tar.bz2: manydhcp/login.php <==
<?php
  ///////////////////////////////////////////////////
  // Вход в систему
  ///////////////////////////////////////////////////
  $lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("lang/".$lang."/".$lang.".php")) {include "lang/".$lang."/".$lang.".php";}
     else {include "lang/ru/ru.php";}

  require_once "config.php";
  require_once "utils/functions.php";

  if(empty($_POST['login'])) {puterrorclr2("Кажется вы забыли ввести логин."); exit();}
  if(empty($_POST['password'])) {puterrorclr2("Кажется вы забыли ввести пароль."); exit();}
  if(strlen($_POST['login'])>200) {puterrorclr2("Логин слишком большой, используйте пожалуйста не больше 100 символов."); exit();}
  if(strlen($_POST['password'])>200) {puterrorclr2("Пароль слишком большой, используйте пожалуйста не больше 100 символов."); exit();}

  if(isset($_POST['login'])) {$login=trim($_POST['login']);}
    else {$login="";}
     if (empty($login)) {puterrorclr2("Пробелы не подойдут в качестве логина..."); exit();}

  if(isset($_POST['password'])) {$password=trim($_POST['password']);}
    else {$password="";}
     if (empty($password)) {puterrorclr2("Пробелы не подойдут в качестве пароля..."); exit();}

  $_POST['login'] = rep($_POST['login']);
  $_POST['password'] = rep($_POST['password']);

//  $_POST['login'] = str_replace("'","`",$_POST['login']);
//  $_POST['password'] = str_replace("'","`",$_POST['password']);
//  $_POST['login'] = htmlspecialchars(stripslashes($_POST['login']));
//  $_POST['password'] = htmlspecialchars(stripslashes($_POST['password']));

  $query = "SELECT login_id, login, pass FROM `tbl_logins` WHERE `login`='".$_POST['login']."' ";
  $result = mysqli_query($dbcnx,$query);
  if(!$result) {puterrorclr2(mysqli_error($dbcnx)); exit();}
      $result2 = mysqli_fetch_array($result,MYSQLI_ASSOC);
      $ident = $result2['login_id'];
  //Проверяем правильность пароля и вычисляем его для хранения в базе
  $passwrd = md5($_POST['password']);
     if($passwrd == $result2['pass'])
     {
       setcookie("passwrd", $passwrd, time()+3600*8);
       setcookie("ident", $ident, time()+3600*8);

       echo "<HTML><HEAD>
             <META HTTP-EQUIV='Refresh' CONTENT='0; URL=main.php'>
             </HEAD>";
     }
     else {puterrorclr2($TEXT['error-loginform1']); exit();}
?>
